package com.wjholden.nmap;

import java.util.ArrayList;
import java.util.List;

import android.util.Log;

/**
 * NmapError is an error logging utility designed to save information
 * that previously went to Log.d. Many users do not know hot to get
 * debugging information from Logcat.
 * 
 * @author William John Holden (wjholden@gmail.com)
 * @version 0.1
 * @since 0.4.1
 */
public class NmapError implements NmapConstants {

	private final transient List<String> errors;
	
	public NmapError()
	{
		errors = new ArrayList<String>();
	}
	
	/**
	 * Commit a new entry into the log.
	 * If Nmap.DEBUG is true then the entry will also output to Logcat.
	 * @param string The String Logged.
	 */
	public void log(final String string)
	{
		if (string == null)
		{
			NmapMain.ne.log("Log was given a null string.");
			return;
		}
		
		errors.add(string);
		if (NmapMain.debug)
		{
			Log.d(TAG, string);
		}
	}
	
	/**
	 * Grabs all lines of output previously stored using NmapError.Log(String).
	 * @return All lines of output, separated by newlines.
	 */
	public String getLog()
	{
		final StringBuilder stringBuilder = new StringBuilder();
		final int stop = errors.size();
		for (int i = 0; i < stop; i++)
		{
			stringBuilder.append(errors.get(i));
			stringBuilder.append('\n');
		}
		return stringBuilder.toString();
	}
}
